# kshell-utilities
Handy utilities for processing nuclear shell model data from `KSHELL`. Se the [KSHELL repository](https://github.com/GaffaSnobb/kshell) for installation and usage instructions for `KSHELL`.

## Installation
Install from the PyPi repository
``` bash
pip install kshell-utilities
```
Or, for the very latest version, clone this repository to your downloads directory. cd to the root directory of this repository and run
```
pip install .
```

## Usage
Please see the *How to use the output from KSHELL* section of the Wiki in the `KSHELL` repository for an introduction on how to use `kshell-utilities`: https://github.com/GaffaSnobb/kshell/wiki/How-to-use-the-output-from-KSHELL

## Credits
KSHELL is created by Noritaka Shimizu https://arxiv.org/abs/1310.5431. Code in this repository is built upon tools created by Jørgen Eriksson Midtbø: https://github.com/jorgenem/kshell_public.
